<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	xmlns="http://www.w3.org/1999/xhtml"
	xmlns:content="http://purl.org/rss/1.0/modules/content/"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:rss="http://purl.org/rss/1.0/"
	xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
	xmlns:dc="http://purl.org/dc/elements/1.1/"
	xmlns:atom="http://www.w3.org/2005/Atom"
	xmlns:ws="http://www.ebenoit.info/data"
	xmlns:wsf="http://www.ebenoit.info/ext">


	<!-- *********************************************************************************************** -->
	<!-- * RSS FEEDS                                                                                   * -->
	<!-- *********************************************************************************************** -->


	<!-- Generate the feeds box
	   -
	   - This template generates a side box for the RSS feeds and calls the appropriate generator
	   - template.
	  -->
	<xsl:template name="generate-feeds-box">
		<xsl:call-template name="side-box-template">
			<xsl:with-param name="id">feeds-box</xsl:with-param>
			<xsl:with-param name="title">
				<xsl:call-template name="get-i18n-string">
					<xsl:with-param name="id">feeds</xsl:with-param>
				</xsl:call-template>
			</xsl:with-param>
			<xsl:with-param name="contents">
				<xsl:call-template name="generate-feeds" />
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>


	<!-- Generate the feeds display
	   -
	   - This template generates the contents of the side box for the RSS feeds.
	  -->
	<xsl:template name="generate-feeds">
		<xsl:choose>

			<xsl:when test="$d/ws:feeds/ws:feed">
				<xsl:for-each select="$d/ws:feeds/ws:feed">
					<xsl:call-template name="generate-feed" />
				</xsl:for-each>
			</xsl:when>

			<xsl:otherwise>
				<div class="line-content">
					<xsl:call-template name="get-i18n-string">
						<xsl:with-param name="id">no-feeds</xsl:with-param>
					</xsl:call-template>
				</div>
			</xsl:otherwise>

		</xsl:choose>
	</xsl:template>


	<!-- Generate a single feed's display
	   -
	   - This template generates the contents that correspond to a single RSS feed.
	  -->
	<xsl:template name="generate-feed">
		<xsl:variable name="feed" select="document( @from )" />
		<xsl:variable name="hide-links" select="@hide-links and @hide-links = '1'" />

		<xsl:choose>
			<xsl:when test="$feed/atom:feed">
				<xsl:for-each select="$feed/atom:feed">
					<xsl:call-template name="generate-atom-feed">
						<xsl:with-param name="hide-links" select="$hide-links" />
					</xsl:call-template>
				</xsl:for-each>
			</xsl:when>
			<xsl:when test="$feed/rdf:RDF/rss:item">
				<xsl:for-each select="$feed/rdf:RDF">
					<xsl:call-template name="generate-rss1-feed">
						<xsl:with-param name="hide-links" select="$hide-links" />
					</xsl:call-template>
				</xsl:for-each>
			</xsl:when>
			<xsl:when test="$feed/rss/channel">
				<xsl:for-each select="$feed/rss/channel">
					<xsl:call-template name="generate-rss2-feed">
						<xsl:with-param name="hide-links" select="$hide-links" />
					</xsl:call-template>
				</xsl:for-each>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<!-- This template generates the contents of the feeds box for an Atom
	   - feed.
	  -->
	<xsl:template name="generate-atom-feed">
		<xsl:param name="hide-links" />

		<div class="feed">
			<div class="feed-title">
				<xsl:value-of select="atom:title" />
			</div>
			<div class="feed-container">
				<xsl:if test="atom:subtitle">
					<div class="feed-description">
						<xsl:value-of select="atom:subtitle" />
					</div>
				</xsl:if>
				<div class="feed-contents">
					<xsl:for-each select="atom:entry[position() &lt;= 5]">
						<xsl:call-template name="generate-atom-item">
							<xsl:with-param name="hide-links" select="$hide-links" />
						</xsl:call-template>
					</xsl:for-each>
				</div>
			</div>
		</div>
	</xsl:template>


	<!-- This template generates the contents that correspond to a single Atom
	   - feed item.
	  -->
	<xsl:template name="generate-atom-item">
		<xsl:param name="hide-links" />

		<div class="feed-item">
			<div class="feed-item-title">
				<xsl:choose>
					<xsl:when test="$hide-links or not(atom:link/@href)">
						<xsl:value-of select="atom:title" disable-output-escaping="no" />
					</xsl:when>
					<xsl:otherwise>
						<a>
							<xsl:attribute name="href">
								<xsl:value-of select="atom:link/@href" />
							</xsl:attribute>
							<xsl:value-of select="atom:title" disable-output-escaping="no" />
						</a>
					</xsl:otherwise>
				</xsl:choose>
			</div>
			<div class="feed-item-date">
				<xsl:if test="atom:author/atom:name and atom:author/atom:name != ''">
					<xsl:value-of select="atom:author/atom:name" /> /
				</xsl:if>
				<xsl:value-of select="atom:published" />
			</div>
		</div>
	</xsl:template>

	<!-- This template generates the contents that correspond to a single
	   - RSS 1.0 feed in the feeds box.
	  -->
	<xsl:template name="generate-rss1-feed">
		<xsl:param name="hide-links" />

		<div class="feed">
			<div class="feed-title">
				<xsl:value-of select="rss:channel/rss:title" />
			</div>
			<div class="feed-container">
				<xsl:if test="rss:channel/rss:description">
					<div class="feed-description">
						<xsl:value-of select="rss:channel/rss:description" />
					</div>
				</xsl:if>
				<div class="feed-contents">
					<xsl:for-each select="rss:item[position() &lt;= 5]">
						<xsl:call-template name="generate-rss1-item">
							<xsl:with-param name="hide-links" select="$hide-links" />
						</xsl:call-template>
					</xsl:for-each>
				</div>
			</div>
		</div>
	</xsl:template>


	<!-- Generate an RSS1 item display
	   -
	   - This template generates the contents that correspond to a single RSS 1 feed item.
	  -->
	<xsl:template name="generate-rss1-item">
		<xsl:param name="hide-links" />

		<div class="feed-item">
			<div class="feed-item-title">
				<xsl:choose>
					<xsl:when test="$hide-links or not(rss:link)">
						<xsl:value-of select="rss:title" disable-output-escaping="no" />
					</xsl:when>
					<xsl:otherwise>
						<a>
							<xsl:attribute name="href">
								<xsl:value-of select="rss:link" />
							</xsl:attribute>
							<xsl:value-of select="rss:title" disable-output-escaping="no" />
						</a>
					</xsl:otherwise>
				</xsl:choose>
			</div>
			<div class="feed-item-date">
				<xsl:if test="dc:creator">
					<xsl:value-of select="dc:creator" /> /
				</xsl:if>
				<xsl:value-of select="dc:date" />
			</div>
		</div>
	</xsl:template>

	<!-- This template generates the contents that correspond to a single
	   - RSS 2 feed in the feeds box.
	  -->
	<xsl:template name="generate-rss2-feed">
		<xsl:param name="hide-links" />

		<div class="feed">
			<div class="feed-title">
				<xsl:value-of select="title" />
			</div>
			<div class="feed-container">
				<xsl:if test="description">
					<div class="feed-description">
						<xsl:value-of select="description" />
					</div>
				</xsl:if>
				<div class="feed-contents">
					<xsl:for-each select="item[position() &lt;= 5]">
						<xsl:call-template name="generate-rss2-item">
							<xsl:with-param name="hide-links" select="$hide-links" />
						</xsl:call-template>
					</xsl:for-each>
				</div>
			</div>
		</div>
	</xsl:template>


	<!-- Generate an RSS2 item display
	   -
	   - This template generates the contents that correspond to a single RSS feed item.
	  -->
	<xsl:template name="generate-rss2-item">
		<xsl:param name="hide-links" />

		<div class="feed-item">
			<div class="feed-item-title">
				<xsl:choose>
					<xsl:when test="$hide-links or not(link)">
						<xsl:value-of select="title" disable-output-escaping="no" />
					</xsl:when>
					<xsl:otherwise>
						<a>
							<xsl:attribute name="href">
								<xsl:value-of select="link" />
							</xsl:attribute>
							<xsl:value-of select="title" disable-output-escaping="yes" />
						</a>
					</xsl:otherwise>
				</xsl:choose>
			</div>
			<div class="feed-item-date">
				<xsl:if test="dc:creator">
					<xsl:value-of select="dc:creator" /> /
				</xsl:if>
				<xsl:value-of select="pubDate" />
			</div>
		</div>
	</xsl:template>


	<!-- This template generates the contents that correspond to a feed
	   - embedded within a page through the <ws:feed /> tag.
	  -->
	<xsl:template name="feed-page">
		<xsl:variable name="feed" select="document( @from )" />
		<xsl:variable name="hide-links" select="@hide-links and @hide-links = '1'" />
		<xsl:variable name="hide-content" select="@hide-content and @hide-content = '1'" />
		<xsl:copy-of select="." />

		<xsl:choose>
			<xsl:when test="$feed/atom:feed">
				<xsl:for-each select="$feed/atom:feed">
					<xsl:call-template name="generate-atom-page">
						<xsl:with-param name="hide-links" select="$hide-links" />
						<xsl:with-param name="hide-content" select="$hide-content" />
					</xsl:call-template>
				</xsl:for-each>
			</xsl:when>
			<xsl:when test="$feed/rdf:RDF/rss:item">
				<xsl:for-each select="$feed/rdf:RDF">
					<xsl:call-template name="generate-rss1-page">
						<xsl:with-param name="hide-links" select="$hide-links" />
						<xsl:with-param name="hide-content" select="$hide-content" />
					</xsl:call-template>
				</xsl:for-each>
			</xsl:when>
			<xsl:when test="$feed/rss/channel">
				<xsl:for-each select="$feed/rss/channel">
					<xsl:call-template name="generate-rss2-page">
						<xsl:with-param name="hide-links" select="$hide-links" />
						<xsl:with-param name="hide-content" select="$hide-content" />
					</xsl:call-template>
				</xsl:for-each>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="generate-rss2-page">
		<xsl:param name="hide-links" />
		<xsl:param name="hide-content" />
		<xsl:call-template name="feed-page-template">
			<xsl:with-param name="title" select="title" />
			<xsl:with-param name="description" select="description" />
			<xsl:with-param name="contents">
				<xsl:for-each select="item">
					<xsl:call-template name="generate-rss2-page-item">
						<xsl:with-param name="hide-links" select="$hide-links" />
						<xsl:with-param name="hide-content" select="$hide-content" />
					</xsl:call-template>
				</xsl:for-each>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="generate-rss2-page-item">
		<xsl:param name="hide-links" />
		<xsl:param name="hide-content" />
		<xsl:call-template name="feed-item-template">
			<xsl:with-param name="title" select="title" />
			<xsl:with-param name="link">
				<xsl:if test="not( $hide-links )">
					<xsl:value-of select="link" />
				</xsl:if>
			</xsl:with-param>
			<xsl:with-param name="author" select="dc:creator" />
			<xsl:with-param name="date" select="pubDate" />
			<xsl:with-param name="content">
				<xsl:choose>
					<xsl:when test="$hide-content" />
					<xsl:when test="content:encoded">
						<xsl:value-of select="content:encoded" disable-output-escaping="yes" />
					</xsl:when>
					<xsl:when test="description">
						<xsl:value-of select="description" disable-output-escaping="yes" />
					</xsl:when>
				</xsl:choose>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="generate-rss1-page">
		<xsl:param name="hide-links" />
		<xsl:param name="hide-content" />
		<xsl:call-template name="feed-page-template">
			<xsl:with-param name="title" select="rss:channel/rss:title" />
			<xsl:with-param name="description" select="rss:channel/rss:description" />
			<xsl:with-param name="contents">
				<xsl:for-each select="rss:item">
					<xsl:call-template name="generate-rss1-page-item">
						<xsl:with-param name="hide-links" select="$hide-links" />
						<xsl:with-param name="hide-content" select="$hide-content" />
					</xsl:call-template>
				</xsl:for-each>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="generate-rss1-page-item">
		<xsl:param name="hide-links" />
		<xsl:param name="hide-content" />
		<xsl:call-template name="feed-item-template">
			<xsl:with-param name="title" select="rss:title" />
			<xsl:with-param name="link">
				<xsl:if test="not( $hide-links )">
					<xsl:value-of select="rss:link" />
				</xsl:if>
			</xsl:with-param>
			<xsl:with-param name="author" select="dc:creator" />
			<xsl:with-param name="date" select="dc:date" />
			<xsl:with-param name="content">
				<xsl:choose>
					<xsl:when test="$hide-content" />
					<xsl:when test="content:encoded">
						<xsl:value-of select="content:encoded" disable-output-escaping="yes" />
					</xsl:when>
					<xsl:when test="rss:description">
						<xsl:value-of select="rss:description" disable-output-escaping="yes" />
					</xsl:when>
				</xsl:choose>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="generate-atom-page">
		<xsl:param name="hide-links" />
		<xsl:param name="hide-content" />
		<xsl:call-template name="feed-page-template">
			<xsl:with-param name="title" select="atom:title" />
			<xsl:with-param name="description" select="atom:subtitle" />
			<xsl:with-param name="contents">
				<xsl:for-each select="atom:entry">
					<xsl:call-template name="generate-atom-page-item">
						<xsl:with-param name="hide-links" select="$hide-links" />
						<xsl:with-param name="hide-content" select="$hide-content" />
					</xsl:call-template>
				</xsl:for-each>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="generate-atom-page-item">
		<xsl:param name="hide-links" />
		<xsl:param name="hide-content" />
		<xsl:call-template name="feed-item-template">
			<xsl:with-param name="title" select="atom:title" />
			<xsl:with-param name="link">
				<xsl:if test="not( $hide-links )">
					<xsl:value-of select="atom:link/@href" />
				</xsl:if>
			</xsl:with-param>
			<xsl:with-param name="author" select="atom:author/atom:name" />
			<xsl:with-param name="date" select="atom:published" />
			<xsl:with-param name="content">
				<xsl:choose>
					<xsl:when test="$hide-content" />
					<xsl:when test="atom:content[ @type = 'html' ]">
						<xsl:value-of select="atom:content[ @type = 'html' ]" disable-output-escaping="yes" />
					</xsl:when>
				</xsl:choose>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

</xsl:stylesheet>
